package de.intevation.flys.client.shared.model;


/** Data matching to labelled integer(s). */
public class IntegerOptionsData implements Data {

    public static final String TYPE = "intoptions";

    protected String label;
    protected String description;

    public DataItem[] opts;


    public IntegerOptionsData() {
    }


    public IntegerOptionsData(String label, String desc, DataItem[] opts) {
        this.label       = label;
        this.description = desc;
        this.opts        = opts;
    }


    /**
     * Returns the label of the item.
     *
     * @return the label.
     */
    public String getLabel() {
        return label;
    }


    /**
     * Returns the description of the item.
     *
     * @return the description.
     */
    public String getDescription() {
        return description;
    }


    /**
     * Returns the type of the item.
     *
     * @return the type.
     */
    public String getType() {
        return TYPE;
    }


    /**
     * Returns the data items which represent the allowed options for this Data.
     *
     * @return the allowed options as DataItem array.
     */
    public DataItem[] getItems() {
        return opts;
    }


    /**
     * @return always null.
     */
    public DataItem getDefault() {
        return null;
    }


    /**
     * Returns the values as colon separated string.
     *
     * @return colon separated string.
     */
    public String getStringValue() {
        String data = "";
        boolean first = true;
        for (int i = 0; i < opts.length; i++) {
            if (!first) {
                data += ";";
            }
            data += opts[i].getStringValue();
            first = false;
        }
        return data;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :

